Stan Math Library: stan/math/fwd/scal/fun/log2.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log2.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_LOG2_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_LOG2_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/constants.hpp>
7 #include <stan/math/prim/scal/fun/log2.hpp>
8
9
10 namespace stan {
11
12 namespace math {
13
14 template <typename T>
15 inline
16 fvar<T>
17 log2(const fvar<T>& x) {
18 using std::log;
19 using stan::math::log2;
20 using stan::math::NOT_A_NUMBER;
21 if (x.val_ < 0.0)
22 return fvar<T>(NOT_A_NUMBER, NOT_A_NUMBER);
23 else
24 return fvar<T>(log2(x.val_), x.d_ / (x.val_ * stan::math::LOG_2));
25 }
26 }
27 }
28 #endif
stan::math::LOG_2
const double LOG_2
The natural logarithm of 2, .
Definition: constants.hpp:33
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::NOT_A_NUMBER
const double NOT_A_NUMBER
(Quiet) not-a-number value.
Definition: constants.hpp:56
stan
Definition: log_sum_exp.hpp:8
stan::math::log
fvar< T > log(const fvar< T > &x)
Definition: log.hpp:15
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
constants.hpp
log2.hpp
stan::math::log2
fvar< T > log2(const fvar< T > &x)
Definition: log2.hpp:17
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.